pygeodesy.sphericalBase.CartesianSphericalBase

Package pygeodesy :: Module sphericalBase :: Class CartesianSphericalBase |
[frames] | no frames]

# Class CartesianSphericalBase

           object --+
                    |
         named._Named --+
                        |
         named._NamedBase --+
                            |
    vector3dBase.Vector3dBase --+
                                |
                vector3d.Vector3d --+
                                    |
                   object --+       |
                            |       |
                 named._Named --+   |
                                |   |
            ecefLocals._EcefLocal --+
                                    |
          cartesianBase.CartesianBase --+
                                        |
                                       CartesianSphericalBase

Known Subclasses:
  - sphericalNvector.Cartesian
  - , sphericalTrigonometry.Cartesian

(INTERNAL) Base class for spherical `Cartesian`s.

Instance Methods
intersections2(self, rad1, other, rad2, radius=6371008.771415) Compute the intersection points of two circles each defined by a center point and a radius. |
Inherited from `cartesianBase.CartesianBase`: `Roc2`, `__init__`, `cassini`, `collins`, `collins5`, `convertDatum`, `destinationXyz`, `hartzell`, `height3`, `height4`, `pierlot`, `pierlotx`, `tienstra`, `tienstra7`, `to2ab`, `to2ll`, `to3llh`, `toDatum`, `toEcef`, `toLatLon`, `toNvector`, `toRtp`, `toStr`, `toTransform`, `toVector` Inherited from `vector3d.Vector3d`: `bearing`, `circin6`, `circum3`, `circum4_`, `iscolinearWith`, `meeus2`, `nearestOn`, `nearestOn6`, `parse`, `radii11`, `soddy4`, `toCartesian`, `trilaterate2d2`, `trilaterate3d2` Inherited from `vector3dBase.Vector3dBase`: `__abs__`, `__add__`, `__bool__`, `__ceil__`, `__cmp__`, `__div__`, `__divmod__`, `__eq__`, `__float__`, `__floor__`, `__floordiv__`, `__ge__`, `__gt__`, `__hash__`, `__iadd__`, `__idiv__`, `__ifloordiv__`, `__imatmul__`, `__imod__`, `__imul__`, `__int__`, `__ipow__`, `__isub__`, `__itruediv__`, `__le__`, `__long__`, `__lt__`, `__matmul__`, `__mod__`, `__mul__`, `__ne__`, `__neg__`, `__nonzero__`, `__pos__`, `__pow__`, `__radd__`, `__rdiv__`, `__rdivmod__`, `__rfloordiv__`, `__rmatmul__`, `__rmod__`, `__rmul__`, `__round__`, `__rpow__`, `__rsub__`, `__rtruediv__`, `__sub__`, `__truediv__`, `__trunc__`, `angleTo`, `apply`, `bools`, `cmp`, `cross`, `dividedBy`, `dividedBy_`, `dot`, `equals`, `equirectangular`, `fabs`, `floats`, `floorDividedBy`, `floorDividedBy_`, `intermediateTo`, `ints`, `isconjugateTo`, `isequalTo`, `minus`, `minus_`, `negate`, `others`, `plus`, `plus_`, `pow`, `rotate`, `rotateAround`, `sum`, `times`, `times_`, `to3xyz`, `unit` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `toRepr` Inherited from `ecefLocals._EcefLocal`: `toAer`, `toEnu`, `toLocal`, `toLtp`, `toNed`, `toXyz` Inherited from `named._Named`: `__format__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| sphericalCartesian Get this `Cartesian`'s spherical class.
Inherited from `cartesianBase.CartesianBase`: `datum`, `ellipsoidalCartesian`, `height`, `isEllipsoidal`, `isSpherical`, `latlon`, `latlonheight`, `latlonheightdatum`, `philam`, `philamheight`, `philamheightdatum` Inherited from `vector3dBase.Vector3dBase`: `crosserrors`, `euclid`, `homogeneous`, `length`, `length2`, `x`, `x2y2z2`, `x2y2z23`, `xyz`, `xyz3`, `y`, `z` Inherited from `ecefLocals._EcefLocal`: `Ecef` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### intersections2 (self, rad1, other, rad2, radius=6371008.771415) |
Compute the intersection points of two circles each defined by a center point and a radius. Arguments: `rad1` - Radius of the this circle (`meter` or `radians`, see `radius`). `other` - Center of the other circle (`Cartesian`). `rad2` - Radius of the other circle (`meter` or `radians`, see `radius`). `radius` - Mean earth radius (`meter` or `None` if both `rad1` and `rad2` are given in `radians`). Returns: 2-Tuple of the intersection points, each `Cartesian`. For abutting circles, the intersection points are the same `Cartesian` instance, aka the radical center. Raises: `IntersectionError` - Concentric, antipodal, invalid or non-intersecting circles. `TypeError` - If `other` is not `Cartesian`. `ValueError` - Invalid `rad1`, `rad2` or `radius`. See Also: Calculating intersection of two Circles and method or function `trilaterate3d2`.

Property Details

### sphericalCartesian Get this `Cartesian`'s spherical class. Get method: sphericalCartesian(self) - Get this `Cartesian`'s spherical class. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.